==> ejc-panhuo-api-3.0.0-20231221.023753-189-sources.jar: com/ejianc/business/panhuo/vo/PutawayDetailVO.java <==
package com.ejianc.business.panhuo.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 批量上架子表
 * 
 * @author generator
 * 
 */
public class PutawayDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long putawayId; // 批量上架主键
    private String billCode; // 资产编号
    private Long toolId; // 机具主键
    private String mainimgPath; // 资产主图URL
    private String spec; // 规格型号
    private String shelfType; // 资产类型
    private Long materialId; // 物资主键
    private String materialCode; // 物资编码
    private String materialName; // 物资名称
    private Long materialTypeId; // 物资类别
    private String materialTypeCode; // 物资类别编码
    private String materialTypeName; // 物资类别名称
    private String sourceType; // 物资来源类型  1-仓库  2-材料档案
    private Long storeId; // 仓库id
    private String storeName; // 仓库name
    private String sourceId; // 物资来源ID
    private Long systemId; // 所属系统ID
    private BigDecimal originalprice; // 原价
    private BigDecimal price; // 单价
    private BigDecimal discount; // 折扣
    private String unit; // 单位
    private BigDecimal averagePrice; // 仓库均价
    private BigDecimal nums; // 数量
    private BigDecimal putawayNums; // 可上架数量
    private String isPack; // 0-是  1-否
    private String details; // 资产详情
    private Integer status; // 资产状态0-在售，1-下架，2-暂存
    private String labelName; // 标签名称
    private Integer type; // 0-手动上架，1-周转上架
    private BigDecimal shelfMny; // 上架总金额
    private BigDecimal storeMny; // 仓库金额
    private String labelIds; // 标签ids
    private java.math.BigDecimal rotatableNums; // 上架数量
    private Long unitId; // 单位

    public Long getUnitId() {
        return unitId;
    }

    public void setUnitId(Long unitId) {
        this.unitId = unitId;
    }

    public BigDecimal getRotatableNums() {
        return rotatableNums;
    }

    public void setRotatableNums(BigDecimal rotatableNums) {
        this.rotatableNums = rotatableNums;
    }

    @ReferSerialTransfer(referCode="panhuoLableRef")
    public String getLabelIds() {
        return labelIds;
    }
    @ReferDeserialTransfer
    public void setLabelIds(String labelIds) {
        this.labelIds = labelIds;
    }

    public Long getPutawayId() {
        return putawayId;
    }

    public void setPutawayId(Long putawayId) {
        this.putawayId = putawayId;
    }
    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getToolId() {
        return toolId;
    }

    public void setToolId(Long toolId) {
        this.toolId = toolId;
    }
    public String getMainimgPath() {
        return mainimgPath;
    }

    public void setMainimgPath(String mainimgPath) {
        this.mainimgPath = mainimgPath;
    }
    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }
    public String getShelfType() {
        return shelfType;
    }

    public void setShelfType(String shelfType) {
        this.shelfType = shelfType;
    }
    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    public String getMaterialCode() {
        return materialCode;
    }

    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }
    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    public Long getMaterialTypeId() {
        return materialTypeId;
    }

    public void setMaterialTypeId(Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }
    public String getMaterialTypeCode() {
        return materialTypeCode;
    }

    public void setMaterialTypeCode(String materialTypeCode) {
        this.materialTypeCode = materialTypeCode;
    }
    public String getMaterialTypeName() {
        return materialTypeName;
    }

    public void setMaterialTypeName(String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }
    public String getSourceType() {
        return sourceType;
    }

    public void setSourceType(String sourceType) {
        this.sourceType = sourceType;
    }
    public Long getStoreId() {
        return storeId;
    }

    public void setStoreId(Long storeId) {
        this.storeId = storeId;
    }
    public String getStoreName() {
        return storeName;
    }

    public void setStoreName(String storeName) {
        this.storeName = storeName;
    }
    public String getSourceId() {
        return sourceId;
    }

    public void setSourceId(String sourceId) {
        this.sourceId = sourceId;
    }
    public Long getSystemId() {
        return systemId;
    }

    public void setSystemId(Long systemId) {
        this.systemId = systemId;
    }
    public BigDecimal getOriginalprice() {
        return originalprice;
    }

    public void setOriginalprice(BigDecimal originalprice) {
        this.originalprice = originalprice;
    }
    public BigDecimal getPrice() {
        return price;
    }

    public void setPrice(BigDecimal price) {
        this.price = price;
    }
    public BigDecimal getDiscount() {
        return discount;
    }

    public void setDiscount(BigDecimal discount) {
        this.discount = discount;
    }
    public String getUnit() {
        return unit;
    }

    public void setUnit(String unit) {
        this.unit = unit;
    }
    public BigDecimal getAveragePrice() {
        return averagePrice;
    }

    public void setAveragePrice(BigDecimal averagePrice) {
        this.averagePrice = averagePrice;
    }
    public BigDecimal getNums() {
        return nums;
    }

    public void setNums(BigDecimal nums) {
        this.nums = nums;
    }
    public BigDecimal getPutawayNums() {
        return putawayNums;
    }

    public void setPutawayNums(BigDecimal putawayNums) {
        this.putawayNums = putawayNums;
    }
    public String getIsPack() {
        return isPack;
    }

    public void setIsPack(String isPack) {
        this.isPack = isPack;
    }
    public String getDetails() {
        return details;
    }

    public void setDetails(String details) {
        this.details = details;
    }
    public Integer getStatus() {
        return status;
    }

    public void setStatus(Integer status) {
        this.status = status;
    }
    public String getLabelName() {
        return labelName;
    }

    public void setLabelName(String labelName) {
        this.labelName = labelName;
    }
    public Integer getType() {
        return type;
    }

    public void setType(Integer type) {
        this.type = type;
    }
    public BigDecimal getShelfMny() {
        return shelfMny;
    }

    public void setShelfMny(BigDecimal shelfMny) {
        this.shelfMny = shelfMny;
    }
    public BigDecimal getStoreMny() {
        return storeMny;
    }

    public void setStoreMny(BigDecimal storeMny) {
        this.storeMny = storeMny;
    }
    
}

==> ejc-panhuo-api-3.0.0-20231226.031417-202-sources.jar: com/ejianc/business/panhuo/vo/PutawayDetailVO.java <==
package com.ejianc.business.panhuo.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 批量上架子表
 * 
 * @author generator
 * 
 */
public class PutawayDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long putawayId; // 批量上架主键
    private String billCode; // 资产编号
    private Long toolId; // 机具主键
    private String mainimgPath; // 资产主图URL
    private String spec; // 规格型号
    private String shelfType; // 资产类型
    private Long materialId; // 物资主键
    private String materialCode; // 物资编码
    private String materialName; // 物资名称
    private Long materialTypeId; // 物资类别
    private String materialTypeCode; // 物资类别编码
    private String materialTypeName; // 物资类别名称
    private String sourceType; // 物资来源类型  1-仓库  2-材料档案
    private Long storeId; // 仓库id
    private String storeName; // 仓库name
    private String sourceId; // 物资来源ID
    private Long systemId; // 所属系统ID
    private BigDecimal originalprice; // 原价
    private BigDecimal price; // 单价
    private BigDecimal discount; // 折扣
    private String unit; // 单位
    private BigDecimal averagePrice; // 仓库均价
    private BigDecimal nums; // 数量
    private BigDecimal putawayNums; // 可上架数量
    private String isPack; // 0-是  1-否
    private String details; // 资产详情
    private Integer status; // 资产状态0-在售，1-下架，2-暂存
    private String labelName; // 标签名称
    private Integer type; // 0-手动上架，1-周转上架
    private BigDecimal shelfMny; // 上架总金额
    private BigDecimal storeMny; // 仓库金额
    private String labelIds; // 标签ids
    private java.math.BigDecimal rotatableNums; // 上架数量
    private Long unitId; // 单位
    private String memo; // 备注

    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }

    public Long getUnitId() {
        return unitId;
    }

    public void setUnitId(Long unitId) {
        this.unitId = unitId;
    }

    public BigDecimal getRotatableNums() {
        return rotatableNums;
    }

    public void setRotatableNums(BigDecimal rotatableNums) {
        this.rotatableNums = rotatableNums;
    }

    @ReferSerialTransfer(referCode="panhuoLableRef")
    public String getLabelIds() {
        return labelIds;
    }
    @ReferDeserialTransfer
    public void setLabelIds(String labelIds) {
        this.labelIds = labelIds;
    }

    public Long getPutawayId() {
        return putawayId;
    }

    public void setPutawayId(Long putawayId) {
        this.putawayId = putawayId;
    }
    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getToolId() {
        return toolId;
    }

    public void setToolId(Long toolId) {
        this.toolId = toolId;
    }
    public String getMainimgPath() {
        return mainimgPath;
    }

    public void setMainimgPath(String mainimgPath) {
        this.mainimgPath = mainimgPath;
    }
    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }
    public String getShelfType() {
        return shelfType;
    }

    public void setShelfType(String shelfType) {
        this.shelfType = shelfType;
    }
    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    public String getMaterialCode() {
        return materialCode;
    }

    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }
    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    public Long getMaterialTypeId() {
        return materialTypeId;
    }

    public void setMaterialTypeId(Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }
    public String getMaterialTypeCode() {
        return materialTypeCode;
    }

    public void setMaterialTypeCode(String materialTypeCode) {
        this.materialTypeCode = materialTypeCode;
    }
    public String getMaterialTypeName() {
        return materialTypeName;
    }

    public void setMaterialTypeName(String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }
    public String getSourceType() {
        return sourceType;
    }

    public void setSourceType(String sourceType) {
        this.sourceType = sourceType;
    }
    public Long getStoreId() {
        return storeId;
    }

    public void setStoreId(Long storeId) {
        this.storeId = storeId;
    }
    public String getStoreName() {
        return storeName;
    }

    public void setStoreName(String storeName) {
        this.storeName = storeName;
    }
    public String getSourceId() {
        return sourceId;
    }

    public void setSourceId(String sourceId) {
        this.sourceId = sourceId;
    }
    public Long getSystemId() {
        return systemId;
    }

    public void setSystemId(Long systemId) {
        this.systemId = systemId;
    }
    public BigDecimal getOriginalprice() {
        return originalprice;
    }

    public void setOriginalprice(BigDecimal originalprice) {
        this.originalprice = originalprice;
    }
    public BigDecimal getPrice() {
        return price;
    }

    public void setPrice(BigDecimal price) {
        this.price = price;
    }
    public BigDecimal getDiscount() {
        return discount;
    }

    public void setDiscount(BigDecimal discount) {
        this.discount = discount;
    }
    public String getUnit() {
        return unit;
    }

    public void setUnit(String unit) {
        this.unit = unit;
    }
    public BigDecimal getAveragePrice() {
        return averagePrice;
    }

    public void setAveragePrice(BigDecimal averagePrice) {
        this.averagePrice = averagePrice;
    }
    public BigDecimal getNums() {
        return nums;
    }

    public void setNums(BigDecimal nums) {
        this.nums = nums;
    }
    public BigDecimal getPutawayNums() {
        return putawayNums;
    }

    public void setPutawayNums(BigDecimal putawayNums) {
        this.putawayNums = putawayNums;
    }
    public String getIsPack() {
        return isPack;
    }

    public void setIsPack(String isPack) {
        this.isPack = isPack;
    }
    public String getDetails() {
        return details;
    }

    public void setDetails(String details) {
        this.details = details;
    }
    public Integer getStatus() {
        return status;
    }

    public void setStatus(Integer status) {
        this.status = status;
    }
    public String getLabelName() {
        return labelName;
    }

    public void setLabelName(String labelName) {
        this.labelName = labelName;
    }
    public Integer getType() {
        return type;
    }

    public void setType(Integer type) {
        this.type = type;
    }
    public BigDecimal getShelfMny() {
        return shelfMny;
    }

    public void setShelfMny(BigDecimal shelfMny) {
        this.shelfMny = shelfMny;
    }
    public BigDecimal getStoreMny() {
        return storeMny;
    }

    public void setStoreMny(BigDecimal storeMny) {
        this.storeMny = storeMny;
    }
    
}
